# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.utils.encoding import python_2_unicode_compatible
from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.conf import settings


@python_2_unicode_compatible
class Country(models.Model):
    """
    International Organization for Standardization (ISO) 3166-1 Country list
    """
    name = models.CharField(
        max_length=128,
        db_index=True,
        verbose_name=_('Official name (CAPS)'),
    )
    printable_name = models.CharField(
        max_length=128,
        db_index=True,
        verbose_name=_('Country name'),
    )
    iso2_code = models.CharField(
        max_length=2,
        unique=True,
        db_index=True,
        verbose_name=_('ISO alpha-2'),
    )
    iso3_code = models.CharField(
        max_length=3,
        unique=True,
        verbose_name=_('ISO alpha-3'),
    )
    numcode = models.PositiveSmallIntegerField(
        null=True,
        blank=True,
        verbose_name=_('ISO numeric'),
    )
    active = models.BooleanField(
        default=True,
        verbose_name=_('Country is active'),
    )
    continent = models.CharField(
        choices=settings.L10N_CONTINENTS,
        max_length=2,
        verbose_name=_('Continent'),
    )
    admin_area = models.CharField(
        choices=settings.L10N_AREAS,
        max_length=2,
        blank=True,
        null=True,
        db_index=True,
        verbose_name=_('Administrative Area'),
    )

    class Meta:
        verbose_name = _('Country')
        verbose_name_plural = _('Countries')
        ordering = ('name',)

    def __str__(self):
        return self.printable_name


@python_2_unicode_compatible
class AdministrativeArea(models.Model):
    """
    Administrative Area level 1 for a country.  For the US, this would be the states
    """
    country = models.ForeignKey(
        Country,
        models.CASCADE,
        related_name='administrative_areas',
        verbose_name=("Country")
    )
    name = models.CharField(
        max_length=60,
        db_index=True,
        verbose_name=_('Admin Area name'),
    )
    abbrev = models.CharField(
        max_length=3,
        blank=True,
        null=True,
        verbose_name=_('Postal Abbreviation'),
    )
    active = models.BooleanField(
        default=True,
        verbose_name=_('Area is active'),
    )

    def __str__(self):
        return self.name

    class Meta:
        verbose_name = _('Administrative Area')
        verbose_name_plural = _('Administrative Areas')
        ordering = ('name',)
